fnss.topologies.topology.Topology.nodes_with_selfloops — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.Topology.nodes_with_selfloops

`Topology.` `nodes_with_selfloops`()

  Return a list of nodes with self loops.

  A node with a self loop has an edge with both ends adjacent to that node.

  Returns : | nodelist : list A list of nodes with self loops.

  See also

  `selfloop_edges`, `number_of_selfloops`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_edge(1,1)
      >>> G.add_edge(1,2)
      >>> G.nodes_with_selfloops()
      [1]

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »